#include <stdio.h>

#define D 0

#define MAXN 200000

struct node{
  int adj;
  int linR = 0;
  int linL = MAXN*10;
  int time;
};

struct edge{
  int cost;
  int next;
  int pointer;
  int nrpasses;
  int timp;
};

int nrE;
struct node tree[MAXN+1];
struct edge edges[MAXN*2];
int dPoints[2];
int dDistance[2][MAXN+1];

int liniarizare[2*MAXN];
int sparstable[2*MAXN + 524288 +1][19];

int nrPos;
int posDpoints[MAXN];

static inline int max(int a, int b){
  return a > b ? a : b;
}

static inline int min(int a, int b){
  return a < b ? a : b;
}

static inline void connect(int p, int c, int cost){
  edges[nrE].cost = cost;
  edges[nrE].pointer = c;
  edges[nrE].next = tree[p].adj;

  tree[p].adj = nrE;

  nrE++;
}

static inline void addEdge(int u, int v, int cost){
  connect(u, v, cost);
  connect(v, u, cost);
}

int farthestPoint, maxDist;
void DFSfarthestpoint(int u, int parent, int dist){
  if(dist > maxDist){
    farthestPoint = u;
    maxDist = dist;
  }

  for(int p = tree[u].adj; p; p = edges[p].next)
    if(edges[p].pointer != parent)
      DFSfarthestpoint(edges[p].pointer, u, dist + edges[p].cost);
}


int origin = 0;
void DFSdist(int u, int parent, int dist){
  dDistance[origin][u] = dist;

  for(int p = tree[u].adj; p; p = edges[p].next)
    if(edges[p].pointer != parent)
      DFSdist(edges[p].pointer, u, dist + edges[p].cost);

}


int posLin;
void DFSlin(int u, int parent, int time){
  tree[u].time = time;
  if(tree[u].linL > posLin)
    tree[u].linL = posLin;

  if(tree[u].linR < posLin)
    tree[u].linR = posLin;

  liniarizare[posLin++] = u;

  for(int p = tree[u].adj; p; p = edges[p].next){
    if(edges[p].pointer != parent){
      DFSlin(edges[p].pointer, u, time+1);

      if(tree[u].linR < posLin)
        tree[u].linR = posLin;
      liniarizare[posLin++] = u;
    }
  }
}

void buildSparseTable(){
  int i, j, pos1, pos2;

  for(i = 0; i < posLin; i++)
    sparstable[i][0] = liniarizare[i];

  for(j = 1; j < 19; j++){
    for(i = 0; i < posLin; i++){
      pos1 = i;
      pos2 = i + (1 << (j-1));
      sparstable[i][j] = (tree[sparstable[pos1][j-1]].time) < (tree[sparstable[pos2][j-1]].time) ? sparstable[pos1][j-1] : sparstable[pos2][j-1];
    }
  }
}


int sparseMin(int l, int r){
  int log = (32 - __builtin_clz(r-l+1) - 1);
  return tree[sparstable[l][log]].time < tree[sparstable[r-(1 << log)][log]].time ? sparstable[l][log] : sparstable[r-(1 << log)][log];
}

int LCA(){
  int l, r, i;

  l = MAXN*10;
  r = 0;
  for(i = 0; i < nrPos; i++){
    if(tree[ posDpoints[i] ].linL < l)
      l = tree[ posDpoints[i] ].linL;
    if(tree[ posDpoints[i] ].linR > r)
      r = tree[ posDpoints[i] ].linR;
  }

  return sparseMin(l, r);
}

int main(){
  int n, k, maxCost, i, a, b, cost, totalCost, diameter, lca;

  scanf("%d%d", &n, &k);
  maxCost = totalCost = 0;
  nrE = 1;
  for(i = 0; i < n-1; i++){
    scanf("%d%d%d", &a, &b, &cost);
    if(cost > maxCost)
      maxCost = cost;
    addEdge(a, b, cost);
    totalCost += cost;
  }

  posLin = 0;
  DFSlin(1, 0, -1);

  if(D){
    for(i = 0; i < posLin; i++)
      printf("%d(%d)  ", liniarizare[i], tree[ liniarizare[i] ].time);

    printf("\n\n");
  }

  buildSparseTable();

  farthestPoint = maxDist = -1;
  DFSfarthestpoint(1, 0, 0);
  dPoints[0] = farthestPoint;

  maxDist = -1;
  DFSfarthestpoint(farthestPoint, 0, 0);
  dPoints[1] = farthestPoint;


  if(k == 0){
    printf("%d\n", maxDist);
  }else if(k == 1){
    diameter = maxDist;

    origin = 0;
    DFSdist(dPoints[0], 0, 0);

    origin = 1;
    DFSdist(dPoints[1], 0, 0);


    nrPos = 0;
    for(i = 1; i <= n; i++){
      if(max(dDistance[0][i], dDistance[1][i]) == diameter)
        posDpoints[nrPos++] = i;
    }

    lca = LCA();
    //printf("LCA: %d\n", lca);

    i = 0;
    while(i < nrPos && posDpoints[i] != lca)
      i++;

    if(i == nrPos)
      printf("%d\n", diameter);
    else
      printf("%d\n", diameter-1);
  }else if(maxCost <= 1){
    diameter = maxDist;

    origin = 0;
    DFSdist(dPoints[0], 0, 0);

    origin = 1;
    DFSdist(dPoints[1], 0, 0);


  }


  return 0;
}
/*
5 6
1 2 5
2 3 11
2 4 3
4 5 2

5 1
1 2 5
2 3 4
2 4 2
4 5 2

6 1
1 2 1
2 3 5
2 4 2
2 6 5
4 5 3

5 6
1 2 1
2 3 1
2 4 1
4 5 1
*/
