#include <stdio.h>
#include <ctype.h>
#include <algorithm>

struct BigNum {
  static const int MAX_DIGITS = 1'000;
  int size;
  char num[MAX_DIGITS];

  void from_int(int x) {
    size = 0;
    while(x > 0) {
      num[size++] = x % 10;
      x /= 10;
    }
  }

  void read() {
    char ch;
    while(isspace(ch = fgetc(stdin)));
    size = 0;
    do {
      num[size++] = ch - '0';
    } while(isdigit(ch = fgetc(stdin)));
    for(int i = 0; i < size / 2; i++) {
      std::swap(num[i], num[size - 1 - i]);
    }
  }

  void operator*=(const int &other) {
    int t = 0;
    for(int i = 0; i < size; i++) {
      t += other * num[i];
      num[i] = t % 10;
      t /= 10;
    }
    while(t > 0) {
      num[size++] = t % 10;
      t /= 10;
    }
  }

  void operator/=(const int &other) {
    int t = 0;
    for(int i = size - 1; i >= 0; i--) {
      t = t * 10 + num[i];
      num[i] = t / other;
      t %= other;
    }
    while(size > 0 && num[size - 1] == 0) {
      size--;
    }
  }
};

using ll = long long;
const int MAX_N = 3'000;
const int MAX_NUM = 100'000;

int a[MAX_N];
int freq[MAX_NUM + 1];

BigNum comb(int n, int k) {
  if(n < k) {
    BigNum ret;
    ret.from_int(0);
    return ret;
  }
  BigNum ret;
  ret.from_int(1);
  for(int i = 1; i <= n; i++) {
    ret *= i;
  }
  for(int i = 1; i <= k; i++) {
    ret /= i;
  }
  for(int i = 1; i <= n - k; i++) {
    ret /= i;
  }
  return ret;
}

bool bigger(BigNum a, BigNum b) {
  if(a.size > b.size) {
    return 1;
  }
  if(a.size < b.size) {
    return 0;
  }
  int i = 0;
  while(i < a.size && a.num[i] == b.num[i]) {
    i++;
  }
  return i >= a.size || a.num[i] > b.num[i];
}

int main() {
  int n, m;
  scanf("%d%d", &n, &m);
  for(int i = 0; i < n; i++) {
    scanf("%d", &a[i]);
    freq[a[i]]++;
  }
  for(int i = 1; i <= MAX_NUM; i++) {
    freq[i] += freq[i - 1];
  }
  for(int i = 0; i < m; i++) {
    int l, r;
    scanf("%d%d", &l, &r);
    BigNum k;
    k.read();
    int total = freq[r] - freq[l - 1];
    int st = 0;
    int max_cresc = (total + 1) / 2;
    int dr = max_cresc + 1;
    while(dr - st > 1) {
      int mij = (st + dr) / 2;
      if(bigger(comb(total, mij), k)) {
        dr = mij;
      } else {
        st = mij;
      }
    }
    printf("%d\n", (dr == max_cresc + 1) ? -1 : dr);
  }

  return 0;
}